/* $Id: resourceids.h,v 1.4 2003/12/13 14:21:26 prussar Exp $ */

#define frmMain             1000
#define frmPrefsButton      1001
#define frmTempButton       1002
#define frmDocListButton    1003
#define frmPrefsRecords     1004
#define frmPrefsSize        1005
#define frmTempRecords      1006
#define frmTempSize         1007
#define frmDocListRecords   1008
#define frmDocListSize      1009
#define frmPrefsNotFound    1011
#define frmPrefsCleared     1012
#define frmTempNotFound     1013
#define frmTempCleared      1014
#define frmDocListNotFound  1015
#define frmDocListCleared   1016
#define frmDone             1017
#define frmWhatIsThis       1018
#define frmFontCacheRecords 1019
#define frmFontCacheSize    1020
#define frmFontCacheButton  1021
#define frmFontCacheNotFound 1022
#define frmFontCacheCleared  1023

#define frmAbout            1100
#define frmAboutOK          1101

#define strWhatIsThis       2000

#define confirmPrefs        3000
#define confirmTemp         3001
#define confirmDocList      3002
#define confirmFontCache    3003
#define errCannotDelete     3004

#define menuMain            4000
#define menuHelpWhatIsThis  4001
#define menuHelpAbout       4002
